/*****************************************************************************/
/* This is a basic HepMCVisual example that can be run from the ROOT         */
/* interactive prompt.                                                       */
/*                                                                           */
/*                                                                           */
/* To run the example:                                                       */ 
/*   - Make sure you have compiled HepMCVisual with the --enable-hepmc-reflex*/
/*     option to ./configure                                                 */
/*   - Make sure libHepMC and libHepMCVisual are in your LD_LIBRARY_PATH     */
/*   - Then from the ROOT prompt type:                                       */
/*     root[0] .L BasicROOT.C                                                */
/*     root[1] ShowExample()                                                 */
/*                                                                           */
/*  In case of problems please write an email to:                            */ 
/*     hepmcvisual@projects.hepforge.org                                     */
/*                                                                           */
/*                                                 Enjoy, Sebastian          */
/*****************************************************************************/

void LoadLibs(){
  //Cintex laden
  gSystem->Load("libCintex.so");
  //enable Cintex
  ROOT::Cintex::Enable();

  //HepMC laden
  gSystem->Load("libHepMC.so");
  //Grafik libraries laden
  gSystem->Load("libGui.so");
  //Library fuer HepMCVisualElements laden
  gSystem->Load("libHepMCVisual.so");
}

void ShowExample(){

  LoadLibs();
  
  using namespace HepMC;
  //Draw a new BrowserFrame
  //VisualBrowserFrame * vbrowser = new VisualBrowserFrame();
  TCanvas * c1 = new TCanvas();
  
  //Get a pdt
  IO_PDG_ParticleDataTable iopdt("PDG_table_2008.mc");
  ParticleDataTable* pdt = iopdt.read_particle_data_table();
  pdt->make_antiparticles_from_particles();
  //pdt->print();

  //Six examples
  using namespace HepMC;
  
  //For simplicity, all particle will have zero four-vector
  //This is a HepLorentzVector for HepMC versions < 2.0 and a HepMC::FourVector
  //for HepMC versions >= 2.0
  FourVector fv(0,0,0,0);

  /**
   * Draw an example with explanations
   **/

  VisualVertex* demo_vertex = new  VisualVertex(.65,.85);
  VisualParticle* demo_particle = new VisualParticle(fv,11);
  demo_particle->SetShow();
  demo_vertex->add_particle_out(demo_particle);
  demo_vertex->Draw();

  TLatex* l=new TLatex(.53,.93,"Drag to move");
  l->SetTextSize(0.03); l->SetTextColor(kGray+2); l->Draw();
  TArrow* a =new TArrow(0.60,.93,.64,.86,.02,"|>");
  a->SetLineColor(kGray+2); a->SetFillColor(kGray+2); a->Draw();
  l = new TLatex(.53,.73,"Double-click to expand all");
  l->SetTextSize(0.03); l->SetTextColor(kGray+2); l->Draw();
  a=new TArrow(0.60,.77,.64,.83,.02,"|>");
  a->SetLineColor(kGray+2); a->SetFillColor(kGray+2); a->Draw();
  l=new TLatex( .69,.77, "Click and hold to show properties");
  l->SetTextSize(0.03); l->SetTextColor(kGray+2); l->Draw();
  a=new TArrow(0.72,.80,.70,.85,.02,"|>");
  a->SetLineColor(kGray+2); a->SetFillColor(kGray+2); a->Draw();
  l=new TLatex( .65, .95,"Click to expand/collapse");
  l->SetTextSize(0.03); l->SetTextColor(kGray+2); l->Draw();
  a=new TArrow(0.70,.93,.67,.86,.02,"|>");
  a->SetLineColor(kGray+2); a->SetFillColor(kGray+2); a->Draw();

 
  /**
   * Now lets draw some simple example of VBF H->bb
   **/
  //One vertex where a quark emits a W- boson (PDG ID=24)
  VisualVertex   * quark_vertex_1 = new VisualVertex(.23,.75);
  VisualParticle * quark1_in = new VisualParticle(fv,1); quark1_in->SetShow();
  VisualParticle * quark1_out = new VisualParticle(fv,2); quark1_out->SetShow();
  VisualParticle * W1 = new VisualParticle(fv,-24);
  W1->SetShow(); W1->SetStaticLabel();
  quark_vertex_1->add_particle_in(quark1_in);
  quark_vertex_1->add_particle_out(quark1_out);
  quark_vertex_1->add_particle_out(W1);

  //Another vertex where a quark emits a W+ boson
  VisualVertex   * quark_vertex_2 = new VisualVertex(.23,.25);
  VisualParticle * quark2_in = new VisualParticle(fv,-1); quark2_in->SetShow();
  VisualParticle * quark2_out = new VisualParticle(fv,-2); quark2_out->SetShow();
  VisualParticle * W2 = new VisualParticle(fv,+24);
  W2->SetShow(); W2->SetStaticLabel();
  quark_vertex_2->add_particle_in(quark2_in);
  quark_vertex_2->add_particle_out(quark2_out);
  quark_vertex_2->add_particle_out(W2);

  //WW scattering (Vector boson fusion) producing a higgs
  VisualVertex   * VBF_vertex = new VisualVertex(.4,.5);
  GenParticle * higgs = new GenParticle(fv,25); //higgs->SetStaticLabel();
  VBF_vertex->add_particle_in(W1);
  VBF_vertex->add_particle_in(W2);
  VBF_vertex->add_particle_out(higgs);

  //Finally higgs decays to bbar, just for fun mix with GenParticles and GenVertex
  GenVertex   * Higgs_vertex = new GenVertex();
  GenParticle * b_out = new GenParticle(fv,5);
  GenParticle * bbar_out = new GenParticle(fv,-5);
  Higgs_vertex->add_particle_in(higgs);
  Higgs_vertex->add_particle_out(b_out);
  Higgs_vertex->add_particle_out(bbar_out);

  
  //Add all these graphs to one events to an event
  VisualEvent* evt = new VisualEvent();
  evt->add_vertex(quark_vertex_1);
  evt->add_vertex(quark_vertex_2);
  evt->add_vertex(VBF_vertex);
  evt->add_vertex(Higgs_vertex);

  //Set the pdg table so we get the PDG information (name, mass, charge...)
  evt->SetPDT(pdt);
  evt->Draw();
}
